@@ -5,7 +5,7 @@ use warnings;
 use DBIx::SchemaChecksum::App;
 
 # PODNAME: scs.pl
-# ABSTRACT: run DBIx::SchemaChecksum
+# ABSTRACT: run DBIx::SchemaChecksum, but really you should use dbchecksum
 
 DBIx::SchemaChecksum::App->new_with_command->run();
 
@@ -17,19 +17,15 @@ __END__
 
 =head1 NAME
 
-scs.pl - run DBIx::SchemaChecksum
+scs.pl - run DBIx::SchemaChecksum, but really you should use dbchecksum
 
 =head1 VERSION
 
-version 1.101
+version 1.102
 
 =head1 USAGE
 
-Please run
-
-  scs.pl help
-
-to get information on available commands and command line options.
+Deprecated, please use C<bin/dbchecksum>
 
 =head1 SEE ALSO
 
