@@ -9,11 +9,8 @@ use Moose::Role;
 around '_build_schemadump_table' => sub {
     my $orig = shift;
     my ($self,$schema,$table) = @_;
-    return if $schema =~ /information_schema/;
 
     die "Sorry, but mysql isn't supported at the moment, because it's introspection seems to be broken.\n";
-
-    return $self->$orig($schema,$table);
 };
 
 1;
@@ -30,7 +27,11 @@ DBIx::SchemaChecksum::Driver::mysql - MySQL driver for DBIx::SchemaChecksum
 
 =head1 VERSION
 
-version 1.101
+version 1.102
+
+=head1 DESCRIPTION
+
+MySQL is B<not> supported!
 
 =head1 AUTHORS
 
